@@ -711,8 +711,7 @@ int  *cs;
       if(*wdp != '\0' && (char*)strstr(wdw, wdp) == wdw) strcpy(kd, wdp);
       else strcpy(kd, wd);
     }
-/* if(Dbg == 'Y')
-   printf("--- kakut --- wdh = %s  wdp = %s  wdw = %s \n",wdh,wdp, wdw);*/
+ // if(Dbg == 'Y') fprintf(dbg, "--- kakut --- wdh = %s  wdp = %s  wdw = %s \n",wdh,wdp, wdw);
     umeKakut(kd, wdw);
     SAIYOU:
     if(index(wdx, '#') || *wdw == '\0') strcpy(en[wc], wdx);
@@ -877,6 +876,7 @@ char kd[], wdw[];
     char k1[45], k2[45], k3[40], k2d[40], hd[2], dmy[2], *ptj, nbstr[3];
     j1 = instrc(kd, '#');
     while(j1 >= 2){
+ if(Dbg == 'Y') fprintf(dbg, "--- umeKakut -- kd = %s wdw = %s \n",kd,wdw);
       left(k1, kd, j1-2);
       n2 = ninstrc(j1, kd, ' ');
       ln = strlen(kd);	right(kd, k2, ln-n2);
