@@ -285,7 +285,32 @@ char wdh[];
     char dums[8], commt[SentLen], cmt2[SentLen], dmy[5], *pt, *pt1;
  if(Dbg == 'Y') fprintf(dbg, "--- predit --- wdh = %s \n", wdh);
     if(*wdh == ' ') ptcut(wdh, 1);
+    // em_bVň͂܂Ă镶ꍇ
+    for(pt = wdh, i=0; pt != NULL; )
+      if(pt = (char*)strstr(pt, "&#8212;")){ pt = pt+7; i++; }
+ if(Dbg == 'Y') fprintf(dbg, "--- predit --- i = %d \n", i);
+    if(i == 2){
+      for(pt = wdh, j=0; pt != NULL; )
+        if(pt = (char*)strstr(pt, "&#8212;")){
+	  if(j==0){ ptreplace(pt, 7, "( "); pt = wdh; j++; }
+	  else { ptreplace(pt, 7, ") "); pt = wdh; j++; }
+        }
+    }
 
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "&#8212;")){ ptreplace(pt, 7, ","); pt = wdh; }
+    for(pt = wdh; pt != NULL; ) // utf em_bV
+      if(pt = (char*)strstr(pt, "\201\\")){ ptreplace(pt, 2, ","); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "g")){ ptreplace(pt, 2, "\""); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "h")){ ptreplace(pt, 2, "\""); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "e")){ ptreplace(pt, 2, "\'"); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "f")){ ptreplace(pt, 2, "\'"); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, "")){ ptreplace(pt, 2, "\\"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
       if(pt = (char*)strstr(pt, "Why don't we")){ ptreplace(pt, 12, "Shall we"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
@@ -316,6 +341,8 @@ char wdh[];
       if(pt = (char*)strstr(pt, ",\"")){ ptreplace(pt, 2, " \" ,"); pt = wdh; }
     for(pt = wdh; pt != NULL; )
       if(pt = (char*)strstr(pt, ".\"")){ ptreplace(pt, 2, " \" ."); pt = wdh; }
+    for(pt = wdh; pt != NULL; )
+      if(pt = (char*)strstr(pt, ".\'\"")){ ptreplace(pt, 3, " \' \" ."); pt = wdh; }
 
 //      if(pt = (char*)strstr(pt, "&quot;")){
 //        if(*(pt+6) != ' '){ ptreplace(pt, 6, "\" "); pt = wdh; }
@@ -521,8 +548,9 @@ char wdh[];
     if((pt = (char*)strstr(wdh, "OK."))){
       if(*pt != ' ') ptinsert(pt+2, " ");
     }
-    if((pt = (char*)strstr(wdh, "s'")) && (char*)strchr(wdh, '\'') < pt){
-      if(*(pt+2) == ' ' || *(pt+2) == '\0' ) ptinsert(pt+1, " ");
+    if((pt = (char*)strstr(wdh, "s'")) && (pt1=(char*)strchr(wdh, '\'')) < pt){
+      if(strncmp(pt1, "'ll", 3) && strncmp(pt1, "'not", 4) )
+        if(*(pt+2) == ' ' || *(pt+2) == '\0' ) ptinsert(pt+1, " ");
     }
     while(*wdh == ' ') ptcut(wdh, 1);
 }
