@@ -16,15 +16,15 @@ char wd[WordLen];
 static char op = 0x28, cp = 0x29;
 char *plu = "addendum,addenda;alga,algae;alto,altos;alumna,alumnae;alumus,alumni;analysis,analyses;antelope,antelopes;antenna,antennas;apex,apexes;appendix,appendixes;aquarium,aquariums;archipelago,archipelagos;automation,automatons;axis,axes;bacillus,bacilli;bacterium,bacteria;banjo,banjoes;basis,bases;brther-in-law,brothers-in-law;buffalo,buffalos;bureau,bureaus;cactus,cacti;calf,calves;cargo,cargos;cello,cellos;chamois,chamois;chassis,chassis;child,children;codex,codices;command,commandos;concerto,concertos;corpus,corpora;crisis,crises;craftsman,craftsmen;criterion,criteria;man,men;shelf,shelves;woman,women;";
 
-static char bungo[14][18] = {"ł","ł( 2)","(ł 3)",
-	"Ȃ( 3)","͂Ȃ","Ȃ","͂Ȃ( 3)",
-	"͖( 3)","Ȃ( 3)","( 3)",
-	"","( 2)","낤","ɂȂ( 3)"},
- 	kougo[14][20] = {"ł","ł","ł","͂܂ł",
-	"͂܂","܂","͂܂ł","͗L܂ł",
-	"܂ł","L܂ł","܂","܂",
-	"ł傤","ɂ܂ł"},
- 	mzn[9][3] = {"","","","","","","","",""},
+//static char bungo[14][18] = {"ł","ł( 2)","(ł 3)",
+//	"Ȃ( 3)","͂Ȃ","Ȃ","͂Ȃ( 3)",
+//	"͖( 3)","Ȃ( 3)","( 3)",
+//	"","( 2)","낤","ɂȂ( 3)"},
+// 	kougo[14][20] = {"ł","ł","ł","͂܂ł",
+//	"͂܂","܂","͂܂ł","͗L܂ł",
+//	"܂ł","L܂ł","܂","܂",
+//	"ł傤","ɂ܂ł"},
+static char 	mzn[9][3] = {"","","","","","","","",""},
  	rny[9][3] = {"","","","","","","","",""},
 	shs[9][3] = {"","","","","","","","",""},
         mei[9][3] = {"","","","","","","","",""},
@@ -473,13 +473,14 @@ char mdi[], mzi[], mdj[], mzj[];
     }
     else{
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 1 %s %s \n", mdj+1, mzj);
-      if(strcmp(mdjb, "SJ") == 0){ strcpy(mdj, sj);  strcpy(mzj, sz); }
+    //      if(strcmp(mdjb, "SJ") == 0){ strcpy(mdj, sj);  strcpy(mzj, sz); }
       if(strchr(mzi, 'p')) return;
       if(strstr(mzj, "") || strchr(mzj, 'n') || strchr(mzj, 'x')) return;
       if(strcmp(mdj+1, "I") == 0 || strcmp(mdj+1, "you") == 0) return;
       if(strcmp(mdj+1, "we") == 0 || strcmp(mdj+1, "they") == 0) return;
-      if(strstr(mdj+1, "men") || strstr(mdj+1, " and ")) return;
-      else if(strstr("he,she,it", mdj+1) || strstr(mzj, "") == 0 || strchr(mzj, 'z') ){
+      if(strcmp(mdj+1, "men") == 0 ) return;
+      //      else if(strstr("he,she,it", mdj+1) || strrchr(mzj, 'z') ){
+      else {
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 2 %s \n", mdj+1);
         if(strcmp(mdi+1, "often happen") == 0){
 	  ptreplace(mdi+1, 12, "often happens");  return;
@@ -785,7 +786,7 @@ char yk[];
     else if(strncmp(yk+1, "may", 3) == 0) ptinsert(yk+4, " not");
     else if(strncmp(yk+1, "must", 4) == 0) ptinsert(yk+5, " not");
     else if(strncmp(yk+1, "will", 4) == 0) ptinsert(yk+5, " not");
-    else if(strncmp(yk+1, "be ", 3) == 0) ptinsert(yk+4, "not");
+    else if(strncmp(yk+1, "be ", 3) == 0) ptinsert(yk+3, " not");
     else if(strncmp(yk+1, "be", 2) == 0 && strlen(yk+1) == 2) ptinsert(yk+3, " not");
     else if(strncmp(yk+1, "is ", 3) == 0) ptinsert(yk+3, " not");
     else if(strncmp(yk+1, "was ", 4) == 0) ptinsert(yk+4, " not");
