@@ -252,6 +252,7 @@ srcUrl(){
 // |{̃Tu
 Jap2Eng(){
     int  ppt, i;
+    char kd[JWordLen];
     ajClear(0);
     if(strlen(jps) > JSentLen){
       if(Dbg == 'Y') fprintf(dbg, "-- Jap2Eng -- %s \n", jps);
@@ -264,37 +265,68 @@ Jap2Eng(){
     for(wnb = 0 ; ; wnb++ ){
       JMP1:
       if(wdh[0] == '\0') break;
+ if(Dbg == 'Y') fprintf(dbg, "-- Jap2Eng head --- wdh = %s wdw = %s \n", wdh, wdw);
       strcpy(wdw, wdh);
       cnb = 0;
-      strncpy(jwd, wdw, 2);
+      if(*wdw == '#'){
+	for(i = 1; i < 10; i++){
+	  if(isalnum(wdw[i]) == 0) break;
+        }
+	strncpy(jwd, wdw, i); // i bytes
+	jwd[i] = '\0';
+ if(Dbg == 'Y') fprintf(dbg, "-- Jap2Eng # --- jwd = %s wdw = %s \n", jwd, wdw);
+      }
+      else{
+        strncpy(jwd, wdw, 2); // 2 bytes
       if(isalnum(*jwd) || (ispunct(*jwd) && !isdigit(*(jwd+1)))
       || *jwd == '[' && isdigit(*(jwd+1)) || isspace(*jwd)) jwd[1] = '\0';
       jwd[2] = '\0';
+      }
       symbck();
       if(ct == 1){
         strcpy(wdx, jwd);    goto JMP;
       }
       wdx[0] = '\0';
+      preEdit();
+      if(strcmp(wdx, "(exit)") == 0) goto JMP1;
+
       for(i = 0; ;i++ ){
         if(i >= 20) error("word cann't be searched !");
 	if(wdx[0] != '\0') break;
         zkc[0] = '\0';
-	preConj();
+	preConj();  // 16/3/31
         if(strcmp(wdx, "(exit)") == 0) goto JMP1;
+
 //        strncpy(jwd, wdw, 2);
 //        jwd[2] = '\0';
+	ct = 0;  // 16/4/20
         ppt = ptcal(wdw);
-      if(Dbg == 'Y') fprintf(dbg, "-- main -- zkc = %s wdw = %s \n", zkc, wdw);
-        diclook(ppt);
+        diclook(ppt);       // Pꌴ`Ō vct=3
+	if(ct == 0){ ct = 1; // 16/4/20
+	  ppt = ptcal(wdw); //
+	  diclook(ppt); // `e̊p`Ō
+	} // 16/4/20
+	if(ct == 1){ ct = 2; // 16/4/20
+	  ppt = ptcal(wdw); //
+	  diclook(ppt); // iAP̌
+	} // 16/4/20
+
+ if(Dbg == 'Y') fprintf(dbg, "-- Jap2Eng -- ct = %d wdx = %s jwd = %s \n", ct, wdx, jwd);
         if(wdx[0] == '\0') jishoFail();
+ if(Dbg == 'Y') fprintf(dbg, "-- Jap2Eng -- wdx = %s wdw = %s \n", wdx, wdw);
       }
       JMP:
       right(wdw, wdh, strlen(wdw)-strlen(jwd));
-    if(Dbg == 'Y') fprintf(dbg, "-- main -- wdh = %s \n", wdh);
+ if(Dbg == 'Y') fprintf(dbg, "--- Jap2Eng --- wdh = %s \n", wdh);
       // "" or "" check
       if(strcmp(caj[0], "S") == 0 || strcmp(caj[0], "O") == 0) goto JMP1;
       strcpy(en[wnb], wdx);
-  if(Dbg == 'Y') fprintf(dbg, "---main --- wdx = %s \n", wdx);
+ if(Dbg == 'Y') fprintf(dbg, "--- Jap2Eng --- wdx = %s jwd = %s \n", wdx, jwd);
+      if(strchr(wdx, '#')) strcpy(kd, wdx); // 16/3/16
+      else strcpy(kd, jwd);
+      umeKakut(kd, wdw);
+
+
       for(i = 0; i <= cnb; i++){
         strcpy(aj[wnb][i], caj[i]);
         strcpy(az[wnb][i], caz[i]);
@@ -368,6 +400,7 @@ char *str;
 
 jishoFail()
 {
+  if(Dbg == 'Y') fprintf(dbg, "--- jishoFail --- wdw = %s \n", wdw);
     if(Conj() == 1) return;
       ct = 0;
       numbck();
@@ -378,6 +411,49 @@ jishoFail()
     strcpy(wdx, jwd);
 }
 
+umeKakut(kd, wdw)
+char kd[], wdw[];
+{
+    int  i, j1, n2, ln, ln1, h2, h3;
+    char k1[45], k2[45], k3[40], k2d[40], hd[2], dmy[2], *ptj, nbstr[3];
+    j1 = instrc(kd, '#');
+    while(j1 >= 2){
+ if(Dbg == 'Y') fprintf(dbg, "--- umeKakut -- kd = %s wdw = %s \n",kd,wdw);
+      left(k1, kd, j1-1);
+      if(isalnum(*(kd+j1))) n2 = j1+1; //16/3/16
+      else n2 = j1; // 16/3/16
+      ln = strlen(kd);	right(kd, k2, ln-n2);
+      if(!isalnum(kd[j1])) hd[0] = '\0'; // 16/3/16
+      else{ hd[0] = kd[j1];	hd[1] = '\0'; }
+      if(kd[ln-1] == '>') cutoff(k2, strlen(k2)-2, 2);
+      h3 = instrc(k2, '#');	ln1 = strlen(k1);
+      if(h3 == 0) h2 = ninstr(ln1+2, wdw, k2);
+      else{ left(k2d, k2,h3-2);	h2 = ninstr(ln1+2, wdw, k2d); }
+      mid(wdw, ln1+1, h2-ln1-1, k3);
+      cutoff(wdw, 0, h2-1);
+      no++;
+      numbtohan(no, nbstr);
+      for(i = 0; i <= YakugoMax; i++){
+	if(!caj[i][0]) break;
+	if(ptj = (char*)index(caj[i], '#')){
+/*	  if(isdigit(*(ptj+1)) != 0) ptj = (char*)index(ptj+2, '#');*/
+	  if(*(ptj+1) >= 0x30 && *(ptj+1) <= 0x39)
+	    ptj = (char*)index(ptj+2,'#');
+	  if(ptj) ptinsert(++ptj, nbstr);
+ if(Dbg == 'Y') fprintf(dbg, "--- umeKakut -- caj[%d] = %s \n",i,caj[i]);
+	}
+      }
+      strcpy(kd, k2);	j1 = instrc(kd, '#');
+      *dmy = no+'0';	dmy[1] = '\0';
+      strink(wdw, "#", dmy, hd, k3, (char*)0);
+ if(Dbg == 'Y') fprintf(dbg, "--- umeKakut --- kd = %s wdw = %s k3 = %s \n", kd, wdw, k3);
+
+      right(wdw, wdh, strlen(wdw)-strlen(kd)); // 16/3/15
+ if(Dbg == 'Y') fprintf(dbg, "--- umeKakut -- wdh = %s l = %d \n", wdh,strlen(kd));
+
+    }
+}
+
 ajClear(t)
 int t;
 {
@@ -472,7 +548,7 @@ siage()
     if(pt) ptreplace(pt, 7, "wasn't");
     if((pt = (char*)strstr(egs, "do not"))) ptreplace(pt, 6, "don't");
     if((pt = (char*)strstr(egs, "does not"))) ptreplace(pt, 8, "doesn't");
-    if((pt = (char*)strstr(egs, "can not"))) ptreplace(pt, 7, "can't");
+    if((pt = (char*)strstr(egs, "can not "))) ptreplace(pt, 8, "can't ");
     if(isalnum(egs[0])) egs[0] = toupper(egs[0]);
     if(Dbg == 'Y') fprintf(dbg, "--- siage --- egs = %s \n", egs);
 }
@@ -481,6 +557,17 @@ siage()
 predit()
 {
     char commt[JSentLen], cmt2[JSentLen], dmy[5], *pt, *pt1;
+    int  i, j;
+    // pSpɕϊ
+    for(i = 0, j = 0; wdh[i] != '\0'; i++, j++){
+      //      if(isalnum(wdh[i])){
+      if(isdigit(wdh[i])){
+        dmy[0] = wdh[i]; dmy[1] = '\0';
+	nhantozen(dmy, commt+j); j++;
+      }
+      else      commt[j] = wdh[i];
+    }
+    commt[j] = '\0';  strcpy(wdh, commt);
     // JbȐ
     pt = wdh;
     if((pt = (char*)strstr(pt, "i")) && (pt1 = (char*)strstr(pt+2, "j"))){
